import ts = require('typescript');
import { AstConverter, AstHandler } from "../converter";
import { OTree } from '../o-tree';
import { ImportStatement } from '../typescript/imports';
/**
 * A basic visitor that applies for most curly-braces-based languages
 */
export declare abstract class DefaultVisitor<C> implements AstHandler<C> {
    abstract readonly defaultContext: C;
    abstract mergeContext(old: C, update: C): C;
    commentRange(node: ts.CommentRange, context: AstConverter<C>): OTree;
    sourceFile(node: ts.SourceFile, context: AstConverter<C>): OTree;
    jsDoc(_node: ts.JSDoc, _context: AstConverter<C>): OTree;
    importStatement(node: ImportStatement, context: AstConverter<C>): OTree;
    functionDeclaration(node: ts.FunctionDeclaration, children: AstConverter<C>): OTree;
    stringLiteral(node: ts.StringLiteral, _children: AstConverter<C>): OTree;
    noSubstitutionTemplateLiteral(node: ts.NoSubstitutionTemplateLiteral, _context: AstConverter<C>): OTree;
    identifier(node: ts.Identifier, _children: AstConverter<C>): OTree;
    block(node: ts.Block, children: AstConverter<C>): OTree;
    parameterDeclaration(node: ts.ParameterDeclaration, children: AstConverter<C>): OTree;
    returnStatement(node: ts.ReturnStatement, children: AstConverter<C>): OTree;
    binaryExpression(node: ts.BinaryExpression, context: AstConverter<C>): OTree;
    prefixUnaryExpression(node: ts.PrefixUnaryExpression, context: AstConverter<C>): OTree;
    ifStatement(node: ts.IfStatement, context: AstConverter<C>): OTree;
    propertyAccessExpression(node: ts.PropertyAccessExpression, context: AstConverter<C>): OTree;
    callExpression(node: ts.CallExpression, context: AstConverter<C>): OTree;
    expressionStatement(node: ts.ExpressionStatement, context: AstConverter<C>): OTree;
    token<A extends ts.SyntaxKind>(node: ts.Token<A>, context: AstConverter<C>): OTree;
    objectLiteralExpression(node: ts.ObjectLiteralExpression, context: AstConverter<C>): OTree;
    newExpression(node: ts.NewExpression, context: AstConverter<C>): OTree;
    propertyAssignment(node: ts.PropertyAssignment, context: AstConverter<C>): OTree;
    variableStatement(node: ts.VariableStatement, context: AstConverter<C>): OTree;
    variableDeclarationList(node: ts.VariableDeclarationList, context: AstConverter<C>): OTree;
    variableDeclaration(node: ts.VariableDeclaration, context: AstConverter<C>): OTree;
    arrayLiteralExpression(node: ts.ArrayLiteralExpression, context: AstConverter<C>): OTree;
    shorthandPropertyAssignment(node: ts.ShorthandPropertyAssignment, context: AstConverter<C>): OTree;
    forOfStatement(node: ts.ForOfStatement, context: AstConverter<C>): OTree;
    classDeclaration(node: ts.ClassDeclaration, context: AstConverter<C>): OTree;
    constructorDeclaration(node: ts.ConstructorDeclaration, context: AstConverter<C>): OTree;
    propertyDeclaration(node: ts.PropertyDeclaration, context: AstConverter<C>): OTree;
    methodDeclaration(node: ts.MethodDeclaration, context: AstConverter<C>): OTree;
    interfaceDeclaration(node: ts.InterfaceDeclaration, context: AstConverter<C>): OTree;
    propertySignature(node: ts.PropertySignature, context: AstConverter<C>): OTree;
    asExpression(node: ts.AsExpression, context: AstConverter<C>): OTree;
    spreadElement(node: ts.SpreadElement, context: AstConverter<C>): OTree;
    spreadAssignment(node: ts.SpreadAssignment, context: AstConverter<C>): OTree;
    ellipsis(_node: ts.SpreadElement | ts.SpreadAssignment, _context: AstConverter<C>): OTree;
    templateExpression(node: ts.TemplateExpression, context: AstConverter<C>): OTree;
    nonNullExpression(node: ts.NonNullExpression, context: AstConverter<C>): OTree;
    parenthesizedExpression(node: ts.ParenthesizedExpression, context: AstConverter<C>): OTree;
    maskingVoidExpression(_node: ts.VoidExpression, _context: AstConverter<C>): OTree;
    private notImplemented;
}
