import ts = require('typescript');
import { AstConverter, AstHandler } from "../converter";
import { OTree } from '../o-tree';
import { ImportStatement } from '../typescript/imports';
export declare class VisualizeAstVisitor implements AstHandler<void> {
    private readonly includeHandlerNames?;
    readonly defaultContext: void;
    constructor(includeHandlerNames?: boolean | undefined);
    mergeContext(_old: void, _update: void): void;
    commentRange(node: ts.CommentRange, context: AstConverter<void>): OTree;
    jsDoc(_node: ts.JSDoc, _context: AstConverter<void>): OTree;
    sourceFile(node: ts.SourceFile, context: AstConverter<void>): OTree;
    importStatement(node: ImportStatement, context: AstConverter<void>): OTree;
    functionDeclaration(node: ts.FunctionDeclaration, children: AstConverter<void>): OTree;
    stringLiteral(node: ts.StringLiteral, children: AstConverter<void>): OTree;
    identifier(node: ts.Identifier, children: AstConverter<void>): OTree;
    block(node: ts.Block, children: AstConverter<void>): OTree;
    parameterDeclaration(node: ts.ParameterDeclaration, children: AstConverter<void>): OTree;
    returnStatement(node: ts.ReturnStatement, children: AstConverter<void>): OTree;
    binaryExpression(node: ts.BinaryExpression, children: AstConverter<void>): OTree;
    ifStatement(node: ts.IfStatement, context: AstConverter<void>): OTree;
    propertyAccessExpression(node: ts.PropertyAccessExpression, context: AstConverter<void>): OTree;
    callExpression(node: ts.CallExpression, context: AstConverter<void>): OTree;
    expressionStatement(node: ts.ExpressionStatement, context: AstConverter<void>): OTree;
    token<A extends ts.SyntaxKind>(node: ts.Token<A>, context: AstConverter<void>): OTree;
    objectLiteralExpression(node: ts.ObjectLiteralExpression, context: AstConverter<void>): OTree;
    newExpression(node: ts.NewExpression, context: AstConverter<void>): OTree;
    propertyAssignment(node: ts.PropertyAssignment, context: AstConverter<void>): OTree;
    variableStatement(node: ts.VariableStatement, context: AstConverter<void>): OTree;
    variableDeclarationList(node: ts.VariableDeclarationList, context: AstConverter<void>): OTree;
    variableDeclaration(node: ts.VariableDeclaration, context: AstConverter<void>): OTree;
    arrayLiteralExpression(node: ts.ArrayLiteralExpression, context: AstConverter<void>): OTree;
    shorthandPropertyAssignment(node: ts.ShorthandPropertyAssignment, context: AstConverter<void>): OTree;
    forOfStatement(node: ts.ForOfStatement, context: AstConverter<void>): OTree;
    classDeclaration(node: ts.ClassDeclaration, context: AstConverter<void>): OTree;
    constructorDeclaration(node: ts.ConstructorDeclaration, context: AstConverter<void>): OTree;
    propertyDeclaration(node: ts.PropertyDeclaration, context: AstConverter<void>): OTree;
    methodDeclaration(node: ts.MethodDeclaration, context: AstConverter<void>): OTree;
    interfaceDeclaration(node: ts.InterfaceDeclaration, context: AstConverter<void>): OTree;
    propertySignature(node: ts.PropertySignature, context: AstConverter<void>): OTree;
    asExpression(node: ts.AsExpression, context: AstConverter<void>): OTree;
    prefixUnaryExpression(node: ts.PrefixUnaryExpression, context: AstConverter<void>): OTree;
    spreadElement(node: ts.SpreadElement, context: AstConverter<void>): OTree;
    spreadAssignment(node: ts.SpreadAssignment, context: AstConverter<void>): OTree;
    ellipsis(node: ts.SpreadAssignment | ts.SpreadElement, context: AstConverter<void>): OTree;
    templateExpression(node: ts.TemplateExpression, context: AstConverter<void>): OTree;
    nonNullExpression(node: ts.NonNullExpression, context: AstConverter<void>): OTree;
    parenthesizedExpression(node: ts.ParenthesizedExpression, context: AstConverter<void>): OTree;
    maskingVoidExpression(node: ts.VoidExpression, context: AstConverter<void>): OTree;
    noSubstitutionTemplateLiteral(node: ts.NoSubstitutionTemplateLiteral, context: AstConverter<void>): OTree;
    private defaultNode;
}
