export interface OTreeOptions {
    /**
     * Adjust indentation with the given number
     *
     * Indentation affects children.
     *
     * @default 0
     */
    indent?: number;
    /**
     * Separate children with the given string
     *
     * @default ''
     */
    separator?: string;
    /**
     * Suffix the token after outdenting
     *
     * @default ''
     */
    suffix?: string;
    /**
     * Whether this part of the generated syntax is okay to insert newlines and comments
     *
     * @default false
     */
    canBreakLine?: boolean;
    /**
     * If set, a unique key which will cause only one node with the given key to be rendered.
     *
     * The outermost key is the one that will be rendered.
     *
     * Used to make it easier to keep the state necessary to render comments
     * only once in the output tree, rather than keep the state in the
     * language rendered.
     *
     * @default No conditional rendering
     */
    renderOnce?: string;
}
/**
 * "Output" Tree
 *
 * Tree-like structure that holds sequences of trees and strings, which
 * can be rendered to an output stream.
 */
export declare class OTree {
    private readonly options;
    static simplify(xs: Array<OTree | string | undefined>): Array<OTree | string>;
    readonly attachComment: boolean;
    private readonly prefix;
    private readonly children;
    constructor(prefix: Array<OTree | string | undefined>, children?: Array<OTree | string | undefined>, options?: OTreeOptions);
    write(sink: OTreeSink): void;
    readonly isEmpty: boolean;
    toString(): string;
}
export declare const NO_SYNTAX: OTree;
export declare class UnknownSyntax extends OTree {
}
export interface SinkMark {
    readonly wroteNonWhitespaceSinceMark: boolean;
}
export declare class OTreeSink {
    private readonly indentLevels;
    private readonly fragments;
    private singletonsRendered;
    private pendingIndentChange;
    tagOnce(key: string | undefined): boolean;
    mark(): SinkMark;
    write(text: string | OTree): void;
    requestIndentChange(x: number): () => void;
    toString(): string;
    private append;
    private applyPendingIndentChange;
    private readonly currentIndent;
}
export declare function renderTree(tree: OTree): string;
