/// <reference types="node" />
import ts = require('typescript');
import { AstHandler, ConvertOptions } from './converter';
import { OTree } from './o-tree';
export interface Source {
    withFile<A>(fn: (fileName: string) => A): A;
    withContents<A>(fn: (fileName: string, contents: string) => A): A;
}
export declare class FileSource implements Source {
    private readonly fileName;
    constructor(fileName: string);
    withFile<A>(fn: (fileName: string) => A): A;
    withContents<A>(fn: (fileName: string, contents: string) => A): A;
}
export declare class LiteralSource implements Source {
    private readonly source;
    private readonly filenameHint;
    constructor(source: string, filenameHint?: string);
    withFile<A>(fn: (fileName: string) => A): A;
    withContents<A>(fn: (fileName: string, contents: string) => A): A;
}
export interface TranslateMarkdownOptions extends ConvertOptions {
    /**
     * What language to put in the returned markdown blocks
     */
    languageIdentifier?: string;
}
export declare function translateMarkdown(markdown: Source, visitor: AstHandler<any>, options?: TranslateMarkdownOptions): TranslateResult;
export declare type TranslateOptions = ConvertOptions;
export declare function translateTypeScript(source: Source, visitor: AstHandler<any>, options?: TranslateOptions): TranslateResult;
export declare function printDiagnostics(diags: ts.Diagnostic[], stream: NodeJS.WritableStream): void;
export declare function printDiagnostic(diag: ts.Diagnostic, stream: NodeJS.WritableStream): void;
export declare function isErrorDiagnostic(diag: ts.Diagnostic): boolean;
export interface TranslateResult {
    tree: OTree;
    diagnostics: ts.Diagnostic[];
}
